import { ComponentProps } from "solid-js";
type TextareaProps = ComponentProps<"textarea">;
type Style = NonNullable<TextareaProps["style"]> & {
    height?: never;
    "max-height"?: never;
    "min-height"?: never;
};
export type TextareaHeightChangeMeta = {
    rowHeight: number;
};
export interface TextareaAutosizeProps extends Omit<TextareaProps, "style"> {
    /**
     * Maximum number of rows up to which the textarea can grow
     */
    maxRows?: number;
    /**
     * Minimum number of rows to show for textarea
     */
    minRows?: number;
    /**
     * Setting rows is not allowed.
     * Use maxRows and minRows instead.
     */
    rows?: never;
    /**
     * Function invoked on textarea height change, with height as first argument.
     * The second function argument is an object containing additional information
     * that might be useful for custom behaviors.
     * Current options include { rowHeight: number }.
     */
    onHeightChange?: (height: number, meta: TextareaHeightChangeMeta) => void;
    /**
     * Reuse previously computed measurements when computing height of textarea. Default: false
     */
    cacheMeasurements?: boolean;
    style?: Style;
}
declare function TextareaAutosize(props: TextareaAutosizeProps & TextareaProps): import("solid-js").JSX.Element;
export default TextareaAutosize;
